@@ -1,8 +1,7 @@
-from . import exclude
-from . import privacy
 from .types import enumerate_sources
 from .common import require
-from .Llama import Llama
+from . import exclude
+from . import privacy
 
 def status_sources(config):
   if not config.sources:
@@ -10,7 +9,7 @@ def status_sources(config):
   lines = []
   for i, src, api in enumerate_sources(config):
     tables, cached = api.list_tables(only_cache=True)
-    lines.append(f'{i:d}: {src["name"]} [{src["id"]}]')
+    lines.append(f'{i:d}: {src["name"]} [{src["type"]}]')
     if cached:
       lines.append(f'   {len(tables)} tables')
     else:
@@ -31,10 +30,3 @@ def status(config):
 def command(args, config):
   require(args == [], 'Unknown command')
   print(status(config))
-
-def shell(args, config):
-  require(args == [], 'Unknown command')
-  import code
-  code.interact('Use "llama" to access data', local={
-    'llama': Llama(config),
-  })
